diff --git a/apps/addressbook/java/src/net/i2p/router/naming/BlockfileNamingService.java b/apps/addressbook/java/src/net/i2p/router/naming/BlockfileNamingService.java
index af8928e1f8b58c09b4b7256adf3bc16e25aa1ec9..f6993d840cdfe9a9bf278caf8f385faff0d89edc 100644
--- a/apps/addressbook/java/src/net/i2p/router/naming/BlockfileNamingService.java
+++ b/apps/addressbook/java/src/net/i2p/router/naming/BlockfileNamingService.java
@@ -98,7 +98,7 @@ import net.metanotion.util.skiplist.SkipList;
  *
  * </pre>
  *
- * All host names are converted to lower case.
+ * All hostnames are converted to lower case.
  *
  * @since 0.8.7, moved from core to addressbook in 0.9.31
  */
diff --git a/apps/i2pcontrol/java/com/thetransactioncompany/jsonrpc2/server/MessageContext.java b/apps/i2pcontrol/java/com/thetransactioncompany/jsonrpc2/server/MessageContext.java
index 1582888d266c0207d2525b668d6d122ae723b930..43d96d7903085a9a4145da23f61e908bd860b75a 100644
--- a/apps/i2pcontrol/java/com/thetransactioncompany/jsonrpc2/server/MessageContext.java
+++ b/apps/i2pcontrol/java/com/thetransactioncompany/jsonrpc2/server/MessageContext.java
@@ -15,7 +15,7 @@ import javax.servlet.http.HttpServletRequest;
  * This class is immutable.
  *
  * <ul>
- *     <li>The client's host name.
+ *     <li>The client's hostname.
  *     <li>The client's IP address.
  *     <li>Whether the request / notification was transmitted securely (e.g. 
  *         via HTTPS).
@@ -122,7 +122,7 @@ public class MessageContext {
 	/**
 	 * Creates a new JSON-RPC 2.0 request / notification context.
 	 *
-	 * @param clientHostName    The client host name, {@code null} if 
+	 * @param clientHostName    The client hostname, {@code null} if 
 	 *                          unknown.
 	 * @param clientInetAddress The client IP address, {@code null} if 
 	 *                          unknown.
@@ -150,7 +150,7 @@ public class MessageContext {
 	/**
 	 * Creates a new JSON-RPC 2.0 request / notification context.
 	 *
-	 * @param clientHostName    The client host name, {@code null} if 
+	 * @param clientHostName    The client hostname, {@code null} if 
 	 *                          unknown.
 	 * @param clientInetAddress The client IP address, {@code null} if 
 	 *                          unknown.
@@ -181,7 +181,7 @@ public class MessageContext {
 	 * Creates a new JSON-RPC 2.0 request / notification context. No 
 	 * authenticated client principal is specified.
 	 *
-	 * @param clientHostName    The client host name, {@code null} if 
+	 * @param clientHostName    The client hostname, {@code null} if 
 	 *                          unknown.
 	 * @param clientInetAddress The client IP address, {@code null} if 
 	 *                          unknown.
@@ -202,7 +202,7 @@ public class MessageContext {
 	 * an insecure transport (plain HTTP) and no authenticated client 
 	 * principal.
 	 *
-	 * @param clientHostName    The client host name, {@code null} if 
+	 * @param clientHostName    The client hostname, {@code null} if 
 	 *                          unknown.
 	 * @param clientInetAddress The client IP address, {@code null} if 
 	 *                          unknown.
@@ -219,7 +219,7 @@ public class MessageContext {
 	/**
 	 * Creates a new JSON-RPC 2.0 request / notification context. Indicates 
 	 * an insecure transport (plain HTTP) and no authenticated client 
-	 * principal. Not client host name / IP is specified.
+	 * principal. Not client hostname / IP is specified.
 	 */
 	public MessageContext() {
 	
@@ -315,10 +315,10 @@ public class MessageContext {
 	
 	
 	/**
-	 * Gets the host name of the client that sent the request / 
+	 * Gets the hostname of the client that sent the request / 
 	 * notification.
 	 *
-	 * @return The client host name, {@code null} if unknown.
+	 * @return The client hostname, {@code null} if unknown.
 	 */
 	public String getClientHostName() {
 	
diff --git a/apps/i2psnark/java/src/org/klomp/snark/PeerCoordinator.java b/apps/i2psnark/java/src/org/klomp/snark/PeerCoordinator.java
index f3b33dee871cf65c51bf2a68ef06655470b34312..03738f122248382a269c24c5a535d7fa12be57d6 100644
--- a/apps/i2psnark/java/src/org/klomp/snark/PeerCoordinator.java
+++ b/apps/i2psnark/java/src/org/klomp/snark/PeerCoordinator.java
@@ -1765,7 +1765,7 @@ class PeerCoordinator implements PeerListener
 
   /**
    *  Ban a web peer for this torrent, for while or permanently.
-   *  @param host the host name
+   *  @param host the hostname
    *  @since 0.9.49
    */
   public synchronized void banWebPeer(String host, boolean isPermanent) {
@@ -1785,7 +1785,7 @@ class PeerCoordinator implements PeerListener
 
   /**
    *  Is a web peer banned?
-   *  @param host the host name
+   *  @param host the hostname
    *  @since 0.9.49
    */
   public synchronized boolean isWebPeerBanned(String host) {
diff --git a/apps/i2psnark/java/src/org/klomp/snark/SnarkManager.java b/apps/i2psnark/java/src/org/klomp/snark/SnarkManager.java
index f513c0594e56622fef4485ffbf8be6451d6bca3c..8e52b053ada5b6a9c3cd92c3e9d5e577763440b4 100644
--- a/apps/i2psnark/java/src/org/klomp/snark/SnarkManager.java
+++ b/apps/i2psnark/java/src/org/klomp/snark/SnarkManager.java
@@ -174,8 +174,8 @@ public class SnarkManager implements CompleteListener, ClientApp {
      *  "name", "announceURL=websiteURL" pairs
      *  '=' in announceURL must be escaped as &#44;
      *
-     *  Please use host name, not b32 or full dest, in announce URL. Ensure in default hosts.txt.
-     *  Please use host name, not b32 or full dest, in website URL. Ensure in default hosts.txt.
+     *  Please use hostname, not b32 or full dest, in announce URL. Ensure in default hosts.txt.
+     *  Please use hostname, not b32 or full dest, in website URL. Ensure in default hosts.txt.
      */
     private static final String DEFAULT_TRACKERS[] = { 
 //       "Postman", "http://YRgrgTLGnbTq2aZOZDJQ~o6Uk5k6TK-OZtx0St9pb0G-5EGYURZioxqYG8AQt~LgyyI~NCj6aYWpPO-150RcEvsfgXLR~CxkkZcVpgt6pns8SRc3Bi-QSAkXpJtloapRGcQfzTtwllokbdC-aMGpeDOjYLd8b5V9Im8wdCHYy7LRFxhEtGb~RL55DA8aYOgEXcTpr6RPPywbV~Qf3q5UK55el6Kex-6VCxreUnPEe4hmTAbqZNR7Fm0hpCiHKGoToRcygafpFqDw5frLXToYiqs9d4liyVB-BcOb0ihORbo0nS3CLmAwZGvdAP8BZ7cIYE3Z9IU9D1G8JCMxWarfKX1pix~6pIA-sp1gKlL1HhYhPMxwyxvuSqx34o3BqU7vdTYwWiLpGM~zU1~j9rHL7x60pVuYaXcFQDR4-QVy26b6Pt6BlAZoFmHhPcAuWfu-SFhjyZYsqzmEmHeYdAwa~HojSbofg0TMUgESRXMw6YThK1KXWeeJVeztGTz25sL8AAAA.i2p/announce.php=http://tracker.postman.i2p/"
@@ -212,7 +212,7 @@ public class SnarkManager implements CompleteListener, ClientApp {
 
     public static final Set<String> DEFAULT_TRACKER_ANNOUNCES;
 
-    /** host names for config form */
+    /** hostnames for config form */
     static final Set<String> KNOWN_OPENTRACKERS = new HashSet<String>(Arrays.asList(new String[] {
         "tracker.welterde.i2p", "cfmqlafjfmgkzbt4r3jsfyhgsr5abgxryl6fnz3d3y5a365di5aa.b32.i2p",
         "opentracker.dg2.i2p", "w7tpbzncbcocrqtwwm3nezhnnsw4ozadvi2hmvzdhrqzfxfum7wa.b32.i2p",
diff --git a/apps/i2psnark/java/src/org/klomp/snark/web/I2PSnarkServlet.java b/apps/i2psnark/java/src/org/klomp/snark/web/I2PSnarkServlet.java
index f8d3e3ca78d361462eecb0a1246d0bcbc63233b3..bf641e39403be8eb86872dba5421ace7b5ad0833 100644
--- a/apps/i2psnark/java/src/org/klomp/snark/web/I2PSnarkServlet.java
+++ b/apps/i2psnark/java/src/org/klomp/snark/web/I2PSnarkServlet.java
@@ -2229,7 +2229,7 @@ public class I2PSnarkServlet extends BasicServlet {
     }
 
     /**
-     *  Full anchor to home page or details page with shortened host name as anchor text
+     *  Full anchor to home page or details page with shortened hostname as anchor text
      *  @return string, non-null
      *  @since 0.9.5
      */
diff --git a/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/I2PTunnelConnectClient.java b/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/I2PTunnelConnectClient.java
index 08f9db34c90e58cdb50801191b671eae827e56f5..5920e9ebea428c4ad59be5f22ad882887e1eec78 100644
--- a/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/I2PTunnelConnectClient.java
+++ b/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/I2PTunnelConnectClient.java
@@ -205,7 +205,7 @@ public class I2PTunnelConnectClient extends I2PTunnelHTTPClientBase implements R
 
                     String hostLowerCase = host.toLowerCase(Locale.US);
                     if (hostLowerCase.endsWith(".i2p")) {
-                        // Destination gets the host name
+                        // Destination gets the hostname
                         destination = host;
                     } else if (host.contains(".") || host.startsWith("[")) {
                         if (Boolean.parseBoolean(getTunnel().getClientOptions().getProperty(PROP_USE_OUTPROXY_PLUGIN, "true"))) {
diff --git a/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/I2PTunnelHTTPClientBase.java b/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/I2PTunnelHTTPClientBase.java
index adf1799cc2caf2869d1566f98c65db4d5044b294..54c7762062ff2ae37589cfc71c6195ce5dd65663 100644
--- a/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/I2PTunnelHTTPClientBase.java
+++ b/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/I2PTunnelHTTPClientBase.java
@@ -762,7 +762,7 @@ public abstract class I2PTunnelHTTPClientBase extends I2PTunnelClientBase implem
         private final boolean _isSSL;
 
         /**
-         *  @param target the URI for an HTTP request, or the host name for CONNECT
+         *  @param target the URI for an HTTP request, or the hostname for CONNECT
          */
         public OnTimeout(Socket s, OutputStream out, String target, boolean usingProxy, String wwwProxy, long id) {
             _socket = s;
@@ -776,7 +776,7 @@ public abstract class I2PTunnelHTTPClientBase extends I2PTunnelClientBase implem
         }
 
         /**
-         *  @param target the URI for an HTTP request, or the host name for CONNECT
+         *  @param target the URI for an HTTP request, or the hostname for CONNECT
          *  @param targetHost if non-null, call noteProxyResult() with this as host
          *  @param isSSL to pass to noteProxyResult(). FALSE for ConnectClient.
          *  @since 0.9.39
@@ -981,7 +981,7 @@ public abstract class I2PTunnelHTTPClientBase extends I2PTunnelClientBase implem
                     out.write(jurl);
                     out.write(uri);
                     out.write("\">");
-                    // Translators: parameter is a host name
+                    // Translators: parameter is a hostname
                     out.write(_t("{0} jump service", jumphost));
                     out.write("</a>\n");
                 }
diff --git a/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/I2Ping.java b/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/I2Ping.java
index 9f858b3c5d0753cb9704954143b70488c2b85cec..a96a9e9f1c82177d12d24d4b6f0bd62ad19b618e 100644
--- a/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/I2Ping.java
+++ b/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/I2Ping.java
@@ -269,7 +269,7 @@ public class I2Ping extends I2PTunnelClientBase {
         /**
          *  As of 0.9.11, does NOT start itself.
          *  Caller must call start()
-         *  @param dest b64 or b32 or host name
+         *  @param dest b64 or b32 or hostname
          */
         public PingHandler(String dest, int count, int fromPort, int toPort,
                            long timeout, boolean countPings, boolean report) {
@@ -335,7 +335,7 @@ public class I2Ping extends I2PTunnelClientBase {
         }
 
         /**
-         *  @param name b64 or b32 or host name
+         *  @param name b64 or b32 or hostname
          *  @since 0.9.11
          */
         private Destination lookup(String name) {
diff --git a/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/SSLClientUtil.java b/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/SSLClientUtil.java
index 37063a3af28e2bf01c3e9996369c40b708bcdac9..63b6718e460057797ba868ac8e080c13affeaad1 100644
--- a/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/SSLClientUtil.java
+++ b/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/SSLClientUtil.java
@@ -137,7 +137,7 @@ public class SSLClientUtil {
             logAlways("Created self-signed certificate for " + cname + " in keystore: " + ks.getAbsolutePath() + "\n" +
                       "The certificate was generated randomly.\n" +
                       "Unless you have changed the default settings, the certificate is not associated with your " +
-                           "IP address, host name, router identity, or destination keys.");
+                           "IP address, hostname, router identity, or destination keys.");
         } else {
             error("Failed to create I2PTunnel SSL keystore.\n" +
                        "If you create the keystore manually, you must add " + optPfx + PROP_KEYSTORE_PASSWORD + " and " + optPfx + PROP_KEY_PASSWORD +
diff --git a/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/socks/SOCKS4aServer.java b/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/socks/SOCKS4aServer.java
index bf18449398b686a44d42fe98bac410134739c094..f3496d77832d1060ca110e3c75754248c0add2b2 100644
--- a/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/socks/SOCKS4aServer.java
+++ b/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/socks/SOCKS4aServer.java
@@ -189,7 +189,7 @@ class SOCKS4aServer extends SOCKSServer {
         setupServer();
 
         if (connHostName == null) {
-            _log.error("BUG: destination host name has not been initialized!");
+            _log.error("BUG: destination hostname has not been initialized!");
             throw new SOCKSException("BUG! See the logs!");
         }
         if (connPort == 0) {
diff --git a/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/socks/SOCKS5Server.java b/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/socks/SOCKS5Server.java
index 8571ddc7c93d3b5a37b95e635ae1497c100871f6..f1c4d170ae836af15ddde3d3ded76274c2403e61 100644
--- a/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/socks/SOCKS5Server.java
+++ b/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/socks/SOCKS5Server.java
@@ -348,7 +348,7 @@ class SOCKS5Server extends SOCKSServer {
         setupServer();
 
         if (connHostName == null) {
-            _log.error("BUG: destination host name has not been initialized!");
+            _log.error("BUG: destination hostname has not been initialized!");
             throw new SOCKSException("BUG! See the logs!");
         }
         if (connPort == 0) {
diff --git a/apps/i2ptunnel/jsp/register.jsp b/apps/i2ptunnel/jsp/register.jsp
index 73112987cca3be8298ee3d50129291f6363df493..f4db356dc4fd16fe1095bfbd25c96f63bcbe7c5d 100644
--- a/apps/i2ptunnel/jsp/register.jsp
+++ b/apps/i2ptunnel/jsp/register.jsp
@@ -112,9 +112,9 @@ input.default { width: 1px; height: 1px; visibility: hidden; }
            %><tr><td class="infohelp"><%=intl._t("Local destination is not available. Start the tunnel.")%></td></tr><%
        } else if (name == null || name.equals("") || name.contains(" ") || !name.endsWith(".i2p")) {
            if (("httpserver".equals(tunnelType)) || ("httpbidirserver".equals(tunnelType))) {
-               %><tr><td class="infohelp"><%=intl._t("To enable registration verification, edit tunnel and set name (or website name) to a valid host name ending in '.i2p'")%></td></tr><%
+               %><tr><td class="infohelp"><%=intl._t("To enable registration verification, edit tunnel and set name (or website name) to a valid hostname ending in '.i2p'")%></td></tr><%
            } else {
-               %><tr><td class="infohelp"><%=intl._t("To enable registration verification, edit tunnel and set name to a valid host name ending in '.i2p'")%></td></tr><%
+               %><tr><td class="infohelp"><%=intl._t("To enable registration verification, edit tunnel and set name to a valid hostname ending in '.i2p'")%></td></tr><%
            }
        } else {
            SigningPrivateKey spk = editBean.getSigningPrivateKey(curTunnel);
@@ -208,7 +208,7 @@ input.default { width: 1px; height: 1px; visibility: hidden; }
 
 <%
                } else {
-                %><tr><td class="infohelp"><%=intl._t("This tunnel must be configured with the new host name.")%>
+                %><tr><td class="infohelp"><%=intl._t("This tunnel must be configured with the new hostname.")%>
                   &nbsp;<%=intl._t("Enter old hostname below.")%></td></tr>
 <%
                }
@@ -240,7 +240,7 @@ input.default { width: 1px; height: 1px; visibility: hidden; }
     </tr>
 <%
                } else {
-                %><tr> <td class="infohelp"><%=intl._t("This tunnel must be configured with the new host name.")%>
+                %><tr> <td class="infohelp"><%=intl._t("This tunnel must be configured with the new hostname.")%>
                   &nbsp;<%=intl._t("Enter old hostname below.")%></td></tr>
 <%
                }
diff --git a/apps/i2ptunnel/jsp/ssl.jsp b/apps/i2ptunnel/jsp/ssl.jsp
index 7ac29d68acd1115818386c9d9d7378495f663198..55c446480f3716a43933b0b60a665c43a60b05f2 100644
--- a/apps/i2ptunnel/jsp/ssl.jsp
+++ b/apps/i2ptunnel/jsp/ssl.jsp
@@ -500,9 +500,9 @@ input.default { width: 1px; height: 1px; visibility: hidden; }
            %><tr><td class="infohelp"><%=intl._t("Local destination is not available. Start the tunnel.")%></td></tr><%
        } else if (name == null || name.equals("") || name.contains(" ") || !name.endsWith(".i2p")) {
            if (("httpserver".equals(tunnelType)) || ("httpbidirserver".equals(tunnelType))) {
-               %><tr><td class="infohelp"><%=intl._t("To enable registration verification, edit tunnel and set name (or website name) to a valid host name ending in '.i2p'")%></td></tr><%
+               %><tr><td class="infohelp"><%=intl._t("To enable registration verification, edit tunnel and set name (or website name) to a valid hostname ending in '.i2p'")%></td></tr><%
            } else {
-               %><tr><td class="infohelp"><%=intl._t("To enable registration verification, edit tunnel and set name to a valid host name ending in '.i2p'")%></td></tr><%
+               %><tr><td class="infohelp"><%=intl._t("To enable registration verification, edit tunnel and set name to a valid hostname ending in '.i2p'")%></td></tr><%
            }
        } else {
            valid = true;
diff --git a/apps/routerconsole/java/src/edu/internet2/ndt/Tcpbw100.java b/apps/routerconsole/java/src/edu/internet2/ndt/Tcpbw100.java
index e3406bd396f5bd02813837895a63dbd48385b9cd..b75974a183af80260ddcf224cb4172f93f2cfbab 100644
--- a/apps/routerconsole/java/src/edu/internet2/ndt/Tcpbw100.java
+++ b/apps/routerconsole/java/src/edu/internet2/ndt/Tcpbw100.java
@@ -1220,7 +1220,7 @@ public class Tcpbw100 extends JApplet implements ActionListener {
 				if ((sName = getParameter(NDTConstants.TARGET1)) == null) {
 					throw new IllegalArgumentException("U parameter Required:");
 				}
-				// host name
+				// hostname
 				if ((sHost = getParameter(NDTConstants.TARGET2)) == null) {
 					throw new IllegalArgumentException("H parameter Required:");
 				}
diff --git a/apps/routerconsole/java/src/net/i2p/router/web/RouterConsoleRunner.java b/apps/routerconsole/java/src/net/i2p/router/web/RouterConsoleRunner.java
index 9101a5495d6e4e23604953270b246590e27022d7..cee4bf331119b01b2d0ccdeddd2f6922159864f4 100644
--- a/apps/routerconsole/java/src/net/i2p/router/web/RouterConsoleRunner.java
+++ b/apps/routerconsole/java/src/net/i2p/router/web/RouterConsoleRunner.java
@@ -953,7 +953,7 @@ public class RouterConsoleRunner implements RouterApp {
             System.err.println("Created self-signed certificate for " + cname + " in keystore: " + ks.getAbsolutePath() + "\n" +
                                "The certificate was generated randomly.\n" +
                                "Unless you have changed the default settings, the certificate is not associated with your " +
-                               "IP address, host name, router identity, or destination keys.");
+                               "IP address, hostname, router identity, or destination keys.");
         } else {
             System.err.println("Failed to create console SSL keystore.\n" +
                                "This is for the Sun/Oracle keytool, others may be incompatible.\n" +
diff --git a/apps/routerconsole/java/src/net/i2p/router/web/helpers/ConfigKeyringHandler.java b/apps/routerconsole/java/src/net/i2p/router/web/helpers/ConfigKeyringHandler.java
index f2052400852ab94040641fa3cdf80e4eaa3c625f..5348bab119ad5947a7c41ce89ed8d36529e3d305 100644
--- a/apps/routerconsole/java/src/net/i2p/router/web/helpers/ConfigKeyringHandler.java
+++ b/apps/routerconsole/java/src/net/i2p/router/web/helpers/ConfigKeyringHandler.java
@@ -84,7 +84,7 @@ public class ConfigKeyringHandler extends FormHandler {
                         spk = bdin.getUnblindedPubKey();
                     }
                     if (spk == null) {
-                        addFormError(_t("Requires host name, destination, or blinded Base32"));
+                        addFormError(_t("Requires hostname, destination, or blinded Base32"));
                         return;
                     }
                     // from BlindCache
diff --git a/apps/routerconsole/java/src/net/i2p/router/web/helpers/ConfigNetHandler.java b/apps/routerconsole/java/src/net/i2p/router/web/helpers/ConfigNetHandler.java
index bb40ab5bac30315199037135fcd929b7c2f963d3..e03e70c1f81bdfed6be87beb5c695362e24ffe9c 100644
--- a/apps/routerconsole/java/src/net/i2p/router/web/helpers/ConfigNetHandler.java
+++ b/apps/routerconsole/java/src/net/i2p/router/web/helpers/ConfigNetHandler.java
@@ -178,7 +178,7 @@ public class ConfigNetHandler extends FormHandler {
             String oldUdp = _context.getProperty(UDPTransport.PROP_SOURCES,
                                                  _context.router().isHidden() ? "hidden" : UDPTransport.DEFAULT_SOURCES);
             String oldUHost = _context.getProperty(UDPTransport.PROP_EXTERNAL_HOST, "");
-            // force change to fixed if user enters a host name/IP
+            // force change to fixed if user enters a hostname/IP
             if (_udpHost1 != null && _udpHost1.length() > 0)
                 _udpAutoIP = "fixed";
             if (_udpAutoIP != null) {
diff --git a/apps/routerconsole/java/src/net/i2p/router/web/helpers/ConfigNetHelper.java b/apps/routerconsole/java/src/net/i2p/router/web/helpers/ConfigNetHelper.java
index 9e98303e13ef77677227c8ded38428cfa048f6a2..a5713a2cbbf688d0d8b419e45e8c22ae9319db09 100644
--- a/apps/routerconsole/java/src/net/i2p/router/web/helpers/ConfigNetHelper.java
+++ b/apps/routerconsole/java/src/net/i2p/router/web/helpers/ConfigNetHelper.java
@@ -247,7 +247,7 @@ public class ConfigNetHelper extends HelperBase {
         }
         if (!addrs.isEmpty()) {
             buf.append("\n<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;")
-               .append(_t("Add host name or IP"))
+               .append(_t("Add hostname or IP"))
                .append(": ");
         }
         buf.append("<input name=\"udpHost1\" type=\"text\" size=\"16\" >");
diff --git a/apps/routerconsole/java/src/net/i2p/router/web/helpers/NetDbHelper.java b/apps/routerconsole/java/src/net/i2p/router/web/helpers/NetDbHelper.java
index 3937da9f1b1941da99242b20cdc8dea3e746c923..9848aa11ca281acc060cd3be9ac5c56424228324 100644
--- a/apps/routerconsole/java/src/net/i2p/router/web/helpers/NetDbHelper.java
+++ b/apps/routerconsole/java/src/net/i2p/router/web/helpers/NetDbHelper.java
@@ -380,7 +380,7 @@ public class NetDbHelper extends FormHandler {
                    "<tr><td>Encryption Type:</td><td><input type=\"text\" name=\"etype\"></td><td></td></tr>\n" +
                    "<tr><td>Router Family:</td><td><input type=\"text\" name=\"fam\"></td><td></td></tr>\n" +
                    "<tr><td>Hash Prefix:</td><td><input type=\"text\" name=\"r\"></td><td></td></tr>\n" +
-                   "<tr><td>IP or Hostname:</td><td><input type=\"text\" name=\"ip\"></td><td>host name, IPv4, or IPv6, /24,/16,/8 suffixes optional for IPv4, prefix ok for IPv6</td></tr>\n" +
+                   "<tr><td>IP or Hostname:</td><td><input type=\"text\" name=\"ip\"></td><td>hostname, IPv4, or IPv6, /24,/16,/8 suffixes optional for IPv4, prefix ok for IPv6</td></tr>\n" +
                    "<tr><td>IPv6 Prefix:</td><td><input type=\"text\" name=\"ipv6\"></td><td></td></tr>\n" +
                    "<tr><td>MTU:</td><td><input type=\"text\" name=\"mtu\"></td><td></td></tr>\n" +
                    "<tr><td>Port Number:</td><td><input type=\"text\" name=\"port\"></td><td></td></tr>\n" +
diff --git a/apps/routerconsole/jsp/confignet.jsp b/apps/routerconsole/jsp/confignet.jsp
index 3b71488582953218386ac4af5c9e0e9c39d6ff72..64edd8b3c783fe831c529d15ecf44a1d8f968020 100644
--- a/apps/routerconsole/jsp/confignet.jsp
+++ b/apps/routerconsole/jsp/confignet.jsp
@@ -71,7 +71,7 @@
     <label><input type="radio" class="optbox" name="udpAutoIP" value="hidden" <%=nethelper.getUdpAutoIPChecked(2) %> >
     <%=intl._t("Hidden mode - do not publish IP")%> <i><%=intl._t("(prevents participating traffic)")%></i></label><br>
     <label><input type="radio" class="optbox" name="udpAutoIP" value="fixed" <%=nethelper.getUdpAutoIPChecked(1) %> >
-    <%=intl._t("Specify host name or IP")%>:</label>
+    <%=intl._t("Specify hostname or IP")%>:</label>
     <%=nethelper.getAddressSelector() %>
   </td>
  </tr>
@@ -149,7 +149,7 @@
     <label><input type="radio" class="optbox" name="ntcpAutoIP" value="disabled" <%=nethelper.getTcpAutoIPChecked(4) %> >
     <%=intl._t("Completely disable")%> <i><%=intl._t("(select only if behind a firewall that throttles or blocks outbound TCP)")%></i></label><br>
     <label><input type="radio" class="optbox" name="ntcpAutoIP" value="false" <%=nethelper.getTcpAutoIPChecked(1) %> >
-    <%=intl._t("Specify host name or IP")%>:</label>
+    <%=intl._t("Specify hostname or IP")%>:</label>
     <input name ="ntcphost" type="text" size="16" value="<jsp:getProperty name="nethelper" property="ntcphostname" />" >
   </td>
  </tr>
diff --git a/apps/sam/java/src/net/i2p/sam/SSLUtil.java b/apps/sam/java/src/net/i2p/sam/SSLUtil.java
index e39fc291d8ce35b9d1ae38ba9d5473048ed6b03d..7bf971ef20078e58c84a61355cb0e6a5929d1f31 100644
--- a/apps/sam/java/src/net/i2p/sam/SSLUtil.java
+++ b/apps/sam/java/src/net/i2p/sam/SSLUtil.java
@@ -102,7 +102,7 @@ class SSLUtil {
         if (success) {
             logAlways("Created self-signed certificate for " + cname + " in keystore: " + ks.getAbsolutePath() + "\n" +
                            "The certificate was generated randomly, and is not associated with your " +
-                           "IP address, host name, router identity, or destination keys.");
+                           "IP address, hostname, router identity, or destination keys.");
         } else {
             error("Failed to create SAM SSL keystore.\n" +
                        "If you create the keystore manually, you must add " + PROP_KEYSTORE_PASSWORD + " and " + PROP_KEY_PASSWORD +
diff --git a/apps/sam/java/src/net/i2p/sam/client/SSLUtil.java b/apps/sam/java/src/net/i2p/sam/client/SSLUtil.java
index f24798047dcaf25506b70ec83c22da3d1dcf6802..e5c4a44b4ea2cc0d944be7d1c931720a8e6abffe 100644
--- a/apps/sam/java/src/net/i2p/sam/client/SSLUtil.java
+++ b/apps/sam/java/src/net/i2p/sam/client/SSLUtil.java
@@ -103,7 +103,7 @@ class SSLUtil {
         if (success) {
             logAlways("Created self-signed certificate for " + cname + " in keystore: " + ks.getAbsolutePath() + "\n" +
                            "The certificate was generated randomly, and is not associated with your " +
-                           "IP address, host name, router identity, or destination keys.");
+                           "IP address, hostname, router identity, or destination keys.");
         } else {
             error("Failed to create SAM SSL keystore.\n" +
                        "If you create the keystore manually, you must add " + PROP_KEYSTORE_PASSWORD + " and " + PROP_KEY_PASSWORD +
diff --git a/apps/susidns/src/java/src/i2p/susi/dns/AddressBean.java b/apps/susidns/src/java/src/i2p/susi/dns/AddressBean.java
index 7bb9b218774787a7bc9e35cf15613672b73dddbb..2835a79690dff746cacbe1490d97807d975b3308 100644
--- a/apps/susidns/src/java/src/i2p/susi/dns/AddressBean.java
+++ b/apps/susidns/src/java/src/i2p/susi/dns/AddressBean.java
@@ -119,7 +119,7 @@ public class AddressBean
 
 		boolean needsIDN = false;
 		// Here we do easy checks and throw translated exceptions.
-		// We do checks on the whole host name, not on each "label", so
+		// We do checks on the whole hostname, not on each "label", so
 		// we allow '.', and some untranslated errors will be thrown by IDN.toASCII()
 		for (int i = 0; i < host.length(); i++) {
 			char c = host.charAt(i);
diff --git a/apps/susidns/src/java/src/i2p/susi/dns/AddressbookBean.java b/apps/susidns/src/java/src/i2p/susi/dns/AddressbookBean.java
index a70efb227204ce0294577ac43774a9c989340841..488730b8753b20bffa673298bbca3b8be9c2ab4c 100644
--- a/apps/susidns/src/java/src/i2p/susi/dns/AddressbookBean.java
+++ b/apps/susidns/src/java/src/i2p/susi/dns/AddressbookBean.java
@@ -310,14 +310,14 @@ public class AddressbookBean extends BaseBean
 									else
 										message = _t("Destination changed for {0}.", displayHost);
 									if (!host.endsWith(".i2p"))
-										message += "<br>" + _t("Warning - host name does not end with \".i2p\"");
+										message += "<br>" + _t("Warning - hostname does not end with \".i2p\"");
 									// clear form
 									hostname = null;
 									destination = null;
 								} else {
 									if (message.length() <= 0) {
 										if (wasB32)
-											message = _t("Invalid Base 32 host name.");
+											message = _t("Invalid Base 32 hostname.");
 										else
 											message = _t("Invalid Base 64 destination.");
 									}
@@ -326,10 +326,10 @@ public class AddressbookBean extends BaseBean
 						} catch (IllegalArgumentException iae) {
 							message = iae.getMessage();
 							if (message == null)
-								message = _t("Invalid host name \"{0}\".", hostname);
+								message = _t("Invalid hostname \"{0}\".", hostname);
 						}
 					} else {
-						message = _t("Please enter a host name and destination");
+						message = _t("Please enter a hostname and destination");
 					}
 					// clear search when adding
 					search = null;
diff --git a/apps/susidns/src/java/src/i2p/susi/dns/NamingServiceBean.java b/apps/susidns/src/java/src/i2p/susi/dns/NamingServiceBean.java
index f094715cb70dabbb8cd826e2e6d5c0118c94d96c..3d96f953d3c8ef01c34358aebae5bda6b598bd75 100644
--- a/apps/susidns/src/java/src/i2p/susi/dns/NamingServiceBean.java
+++ b/apps/susidns/src/java/src/i2p/susi/dns/NamingServiceBean.java
@@ -319,7 +319,7 @@ public class NamingServiceBean extends AddressbookBean
 										else
 											message = _t("Destination changed for {0}.", displayHost);
 										if (!host.endsWith(".i2p"))
-											message += "<br>" + _t("Warning - host name does not end with \".i2p\"");
+											message += "<br>" + _t("Warning - hostname does not end with \".i2p\"");
 										// clear form
 										hostname = null;
 										destination = null;
@@ -331,7 +331,7 @@ public class NamingServiceBean extends AddressbookBean
 									if (msg != null && msg.length() > 0)
 										message = msg;
 									else if (wasB32)
-										message = _t("Invalid Base 32 host name.");
+										message = _t("Invalid Base 32 hostname.");
 									else
 										message = _t("Invalid Base 64 destination.");
 								}
@@ -339,10 +339,10 @@ public class NamingServiceBean extends AddressbookBean
 						} catch (IllegalArgumentException iae) {
 							message = iae.getMessage();
 							if (message == null)
-								message = _t("Invalid host name \"{0}\".", hostname);
+								message = _t("Invalid hostname \"{0}\".", hostname);
 						}
 					} else {
-						message = _t("Please enter a host name and destination");
+						message = _t("Please enter a hostname and destination");
 					}
 					// clear search when adding
 					search = null;
@@ -375,7 +375,7 @@ public class NamingServiceBean extends AddressbookBean
 					}
 					if( changed ) {
 						if (deleted == 1)
-							// parameter is a host name
+							// parameter is a hostname
 							message += _t("Destination {0} deleted.", name);
 						else
 							// parameter will always be >= 2
diff --git a/core/java/src/net/i2p/client/I2PSession.java b/core/java/src/net/i2p/client/I2PSession.java
index 84a3e931792096489e3d05d871bf858568de78a9..d280081e60b0e3a3cc8a0b3ec7fddb827f143653 100644
--- a/core/java/src/net/i2p/client/I2PSession.java
+++ b/core/java/src/net/i2p/client/I2PSession.java
@@ -349,7 +349,7 @@ public interface I2PSession {
     public Destination lookupDest(Hash h, long maxWait) throws I2PSessionException;
 
     /**
-     *  Ask the router to lookup a Destination by host name.
+     *  Ask the router to lookup a Destination by hostname.
      *  Blocking. Waits a max of 10 seconds by default.
      *
      *  This only makes sense for a b32 hostname, OR outside router context.
@@ -402,7 +402,7 @@ public interface I2PSession {
     public Destination lookupDest(String name) throws I2PSessionException;
 
     /**
-     *  Ask the router to lookup a Destination by host name.
+     *  Ask the router to lookup a Destination by hostname.
      *  Blocking. See above for details.
      *  @param maxWait ms
      *  @since 0.9.11
@@ -411,7 +411,7 @@ public interface I2PSession {
     public Destination lookupDest(String name, long maxWait) throws I2PSessionException;
 
     /**
-     *  Ask the router to lookup a Destination by host name.
+     *  Ask the router to lookup a Destination by hostname.
      *  Blocking. See above for details.
      *  Same as lookupDest() but with a failure code in the return value
      *
diff --git a/core/java/src/net/i2p/client/impl/I2PSessionImpl.java b/core/java/src/net/i2p/client/impl/I2PSessionImpl.java
index b7008eae97a49f170b7fa9766f4b3d0a23321bcc..cb4190d6c9ad13baf78da2ed8787f8c84c1cad99 100644
--- a/core/java/src/net/i2p/client/impl/I2PSessionImpl.java
+++ b/core/java/src/net/i2p/client/impl/I2PSessionImpl.java
@@ -1707,7 +1707,7 @@ public abstract class I2PSessionImpl implements I2PSession, I2CPMessageReader.I2
     }
 
     /**
-     *  Ask the router to lookup a Destination by host name.
+     *  Ask the router to lookup a Destination by hostname.
      *  Blocking. Waits a max of 10 seconds by default.
      *
      *  This only makes sense for a b32 hostname, OR outside router context.
@@ -1729,7 +1729,7 @@ public abstract class I2PSessionImpl implements I2PSession, I2CPMessageReader.I2
     }
 
     /**
-     *  Ask the router to lookup a Destination by host name.
+     *  Ask the router to lookup a Destination by hostname.
      *  Blocking. See above for details.
      *  @param maxWait ms
      *  @since 0.9.11
@@ -1745,7 +1745,7 @@ public abstract class I2PSessionImpl implements I2PSession, I2CPMessageReader.I2
     }
 
     /**
-     *  Ask the router to lookup a Destination by host name.
+     *  Ask the router to lookup a Destination by hostname.
      *  Blocking. See above for details.
      *  Same as lookupDest() but with a failure code in the return value
      *
@@ -1767,7 +1767,7 @@ public abstract class I2PSessionImpl implements I2PSession, I2CPMessageReader.I2
     }
 
     /**
-     *  Ask the router to lookup a Destination by host name.
+     *  Ask the router to lookup a Destination by hostname.
      *  Blocking. See above for details.
      *  @param maxWait ms
      *  @since 0.9.11
diff --git a/core/java/src/net/i2p/client/impl/SubSession.java b/core/java/src/net/i2p/client/impl/SubSession.java
index 5a7dfc069fb16b94283d47f52e8f829a45ee11d1..63a37a4f032c33ce00668d1ef1dc42dde831f8c7 100644
--- a/core/java/src/net/i2p/client/impl/SubSession.java
+++ b/core/java/src/net/i2p/client/impl/SubSession.java
@@ -300,7 +300,7 @@ class SubSession extends I2PSessionMuxedImpl {
     }
 
     /**
-     *  Ask the router to lookup a Destination by host name.
+     *  Ask the router to lookup a Destination by hostname.
      *  Blocking. Waits a max of 10 seconds by default.
      *
      *  This only makes sense for a b32 hostname, OR outside router context.
@@ -321,7 +321,7 @@ class SubSession extends I2PSessionMuxedImpl {
     }
 
     /**
-     *  Ask the router to lookup a Destination by host name.
+     *  Ask the router to lookup a Destination by hostname.
      *  Blocking. See above for details.
      *  @param maxWait ms
      *  @return null on failure
diff --git a/core/java/src/net/i2p/client/naming/HostsTxtNamingService.java b/core/java/src/net/i2p/client/naming/HostsTxtNamingService.java
index 7887e4acaeabfadc0019755be7a27bcd1337c0e7..4e2d3cfe6ecc533d0d0034d4658683a242a6ebae 100644
--- a/core/java/src/net/i2p/client/naming/HostsTxtNamingService.java
+++ b/core/java/src/net/i2p/client/naming/HostsTxtNamingService.java
@@ -22,7 +22,7 @@ import net.i2p.data.Destination;
  * A naming service based on multiple "hosts.txt" files.
  * Supports .b32.i2p and {b64} lookups.
  * Supports caching.
- * All host names are converted to lower case.
+ * All hostnames are converted to lower case.
  */
 public class HostsTxtNamingService extends MetaNamingService {
 
diff --git a/core/java/src/net/i2p/client/naming/NamingService.java b/core/java/src/net/i2p/client/naming/NamingService.java
index 2b7742c9964013ba787cfa156b640c4e374274af..e45f29fa9345e4af7e37d14a680bf61eb8ad45b1 100644
--- a/core/java/src/net/i2p/client/naming/NamingService.java
+++ b/core/java/src/net/i2p/client/naming/NamingService.java
@@ -55,8 +55,8 @@ public abstract class NamingService {
     }
     
     /**
-     * Look up a host name.
-     * @return the Destination for this host name, or
+     * Look up a hostname.
+     * @return the Destination for this hostname, or
      * <code>null</code> if name is unknown.
      */
     public Destination lookup(String hostname) {
@@ -68,7 +68,7 @@ public abstract class NamingService {
      * This implementation returns reverseLookup(dest, null).
      *
      * @param dest non-null
-     * @return a host name for this Destination, or <code>null</code>
+     * @return a hostname for this Destination, or <code>null</code>
      * if none is known. It is safe for subclasses to always return
      * <code>null</code> if no reverse lookup is possible.
      */
@@ -82,14 +82,14 @@ public abstract class NamingService {
      * Subclasses implementing reverse lookups should override.
      *
      * @param h non-null
-     * @return a host name for this hash, or <code>null</code>
+     * @return a hostname for this hash, or <code>null</code>
      * if none is known. It is safe for subclasses to always return
      * <code>null</code> if no reverse lookup is possible.
      */
     public String reverseLookup(Hash h) { return null; }
 
     /**
-     * If the host name is a valid Base64 encoded destination, return the
+     * If the hostname is a valid Base64 encoded destination, return the
      * decoded Destination. Useful as a "fallback" in custom naming
      * implementations.
      * This is misnamed as it isn't a "lookup" at all, but
@@ -342,7 +342,7 @@ public abstract class NamingService {
     }
 
     /**
-     *  @return all known host names
+     *  @return all known hostnames
      *          or empty Set if none;
      *          Returned Set is not necessarily sorted, implementation dependent
      *  @since 0.8.7
@@ -353,7 +353,7 @@ public abstract class NamingService {
 
     /**
      *  @param options NamingService-specific, can be null
-     *  @return all known host names (matching the options if non-null)
+     *  @return all known hostnames (matching the options if non-null)
      *          or empty Set if none;
      *          Returned Set is not necessarily sorted, implementation dependent
      *  @since 0.8.7
@@ -521,7 +521,7 @@ public abstract class NamingService {
      *
      *  @param d non-null
      *  @param options NamingService-specific, can be null
-     *  @return host name or null
+     *  @return hostname or null
      *  @since 0.8.7
      */
     public String reverseLookup(Destination d, Properties options) {
@@ -576,7 +576,7 @@ public abstract class NamingService {
     //// Begin new API for multiple Destinations
 
     /**
-     *  For NamingServices that support multiple Destinations for a single host name,
+     *  For NamingServices that support multiple Destinations for a single hostname,
      *  return all of them.
      *
      *  It is recommended that the returned list is in order of priority, highest-first,
@@ -594,7 +594,7 @@ public abstract class NamingService {
     }
 
     /**
-     *  For NamingServices that support multiple Destinations and Properties for a single host name,
+     *  For NamingServices that support multiple Destinations and Properties for a single hostname,
      *  return all of them.
      *
      *  It is recommended that the returned list is in order of priority, highest-first,
@@ -698,7 +698,7 @@ public abstract class NamingService {
      * Subclasses implementing reverse lookups should override.
      *
      * @param h non-null
-     * @return a non-empty list of host names for this hash, or <code>null</code>
+     * @return a non-empty list of hostnames for this hash, or <code>null</code>
      * if none is known. It is safe for subclasses to always return
      * <code>null</code> if no reverse lookup is possible.
      * @since 0.9.26
@@ -713,7 +713,7 @@ public abstract class NamingService {
      * This implementation returns reverseLookupAll(dest, null).
      *
      * @param dest non-null
-     * @return a non-empty list of host names for this Destination, or <code>null</code>
+     * @return a non-empty list of hostnames for this Destination, or <code>null</code>
      * if none is known. It is safe for subclasses to always return
      * <code>null</code> if no reverse lookup is possible.
      * @since 0.9.26
@@ -729,7 +729,7 @@ public abstract class NamingService {
      *
      *  @param d non-null
      *  @param options NamingService-specific, can be null
-     *  @return a non-empty list of host names for this Destination, or <code>null</code>
+     *  @return a non-empty list of hostnames for this Destination, or <code>null</code>
      *  @since 0.9.26
      */
     public List<String> reverseLookupAll(Destination d, Properties options) {
diff --git a/core/java/src/net/i2p/client/naming/SingleFileNamingService.java b/core/java/src/net/i2p/client/naming/SingleFileNamingService.java
index 48182c7bc17f6373152cdbfabe8578186805d68b..dfe4d270f3681e296dbe59b468f940566d4e569f 100644
--- a/core/java/src/net/i2p/client/naming/SingleFileNamingService.java
+++ b/core/java/src/net/i2p/client/naming/SingleFileNamingService.java
@@ -509,7 +509,7 @@ public class SingleFileNamingService extends NamingService {
 
     /**
      *  @param options ignored
-     *  @return all known host names, unsorted
+     *  @return all known hostnames, unsorted
      */
     public Set<String> getNames(Properties options) {
         if (!_file.exists())
diff --git a/core/java/src/net/i2p/util/Addresses.java b/core/java/src/net/i2p/util/Addresses.java
index fd2df3369d177b2d390ca6e66b0bd78c7f8d3687..def047814206e6dace048021afc0a73de8fc42e0 100644
--- a/core/java/src/net/i2p/util/Addresses.java
+++ b/core/java/src/net/i2p/util/Addresses.java
@@ -390,8 +390,8 @@ public abstract class Addresses {
 
     /**
      *  Caching version of InetAddress.getByName(host).getAddress(), which is slow.
-     *  Caches numeric host names only.
-     *  Will resolve but not cache DNS host names.
+     *  Caches numeric hostnames only.
+     *  Will resolve but not cache DNS hostnames.
      *
      *  Unlike InetAddress.getByName(), we do NOT allow numeric IPs
      *  of the form d.d.d, d.d, or d, as these are almost certainly mistakes.
@@ -402,7 +402,7 @@ public abstract class Addresses {
      *  InetAddress.getByName() also returns 127.0.0.1 for a host "",
      *  but this is undocumented; as of 0.9.49, here we return null.
      *
-     *  @param host DNS or IPv4 or IPv6 host name; if null or empty returns null
+     *  @param host DNS or IPv4 or IPv6 hostname; if null or empty returns null
      *  @return IP or null
      *  @since 0.9.3
      */
@@ -443,7 +443,7 @@ public abstract class Addresses {
     /**
      *  Caching version of InetAddress.getByName(host).getAddress(), which is slow.
      *  Resolves literal IP addresses only, will not cause a DNS lookup.
-     *  Will return null for host names.
+     *  Will return null for hostnames.
      *
      *  Unlike InetAddress.getByName(), we do NOT allow numeric IPs
      *  of the form d.d.d, d.d, or d, as these are almost certainly mistakes.
@@ -476,11 +476,11 @@ public abstract class Addresses {
 
     /**
      *  For literal IP addresses, this is the same as getIP(String).
-     *  For host names, will return the preferred type (IPv4/v6) if available,
+     *  For hostnames, will return the preferred type (IPv4/v6) if available,
      *  else the other type if available.
-     *  Will resolve but not cache DNS host names.
+     *  Will resolve but not cache DNS hostnames.
      *
-     *  @param host DNS or IPv4 or IPv6 host name; if null returns null
+     *  @param host DNS or IPv4 or IPv6 hostname; if null returns null
      *  @return IP or null
      *  @since 0.9.28
      */
@@ -522,9 +522,9 @@ public abstract class Addresses {
 
     /**
      *  For literal IP addresses, this is the same as getIP(String).
-     *  For host names, may return multiple addresses, both IPv4 and IPv6,
+     *  For hostnames, may return multiple addresses, both IPv4 and IPv6,
      *  even if those addresses are not reachable due to configuration or available interfaces.
-     *  Will resolve but not cache DNS host names.
+     *  Will resolve but not cache DNS hostnames.
      *
      *  Note that order of returned results, and whether
      *  multiple results for either IPv4 or IPv6 or both are actually
@@ -533,7 +533,7 @@ public abstract class Addresses {
      *  Number of results may also change based on caching at various layers,
      *  even if the ultimate name server results did not change.
      *
-     *  @param host DNS or IPv4 or IPv6 host name; if null returns null
+     *  @param host DNS or IPv4 or IPv6 hostname; if null returns null
      *  @return non-empty list IPs, or null if none
      *  @since 0.9.28
      */
diff --git a/core/java/src/net/i2p/util/I2PSSLSocketFactory.java b/core/java/src/net/i2p/util/I2PSSLSocketFactory.java
index 45a007d1650971a56b0a5ad1f41ccb722c6c73df..6cb11ac2a7ffcb5c66ea1c68e06fe5c07dbc0698 100644
--- a/core/java/src/net/i2p/util/I2PSSLSocketFactory.java
+++ b/core/java/src/net/i2p/util/I2PSSLSocketFactory.java
@@ -249,7 +249,7 @@ public class I2PSSLSocketFactory {
     /**
      * Returns a socket to the host.
      *
-     * A host argument that's an IP address (instead of a host name)
+     * A host argument that's an IP address (instead of a hostname)
      * is not recommended, as this will probably fail
      * SSL certificate validation.
      *
@@ -267,9 +267,9 @@ public class I2PSSLSocketFactory {
     /**
      * Returns a socket to the host.
      *
-     * An InetAddress argument created with an IP address (instead of a host name)
+     * An InetAddress argument created with an IP address (instead of a hostname)
      * is not recommended, as this will perform a reverse DNS lookup to
-     * get the host name for certificate validation, which will probably then fail.
+     * get the hostname for certificate validation, which will probably then fail.
      *
      * Hostname validation is skipped for localhost addresses, but you still
      * must trust the certificate.
diff --git a/router/java/src/net/i2p/data/router/RouterAddress.java b/router/java/src/net/i2p/data/router/RouterAddress.java
index a56c31c3fe4218c31f541cb45b72fa6ecc32ec85..e2f7d95e6807aac471cbdf7aefaa073822244acb 100644
--- a/router/java/src/net/i2p/data/router/RouterAddress.java
+++ b/router/java/src/net/i2p/data/router/RouterAddress.java
@@ -215,11 +215,11 @@ public class RouterAddress extends DataStructureImpl {
     
     /**
      *  Caching version of InetAddress.getByName(getOption("host")).getAddress(), which is slow.
-     *  Caches numeric host names, and negative caches also.
+     *  Caches numeric hostnames, and negative caches also.
      *
-     *  As of 0.9.32, this works for literal IP addresses only, and does NOT resolve host names.
-     *  If a host name is specified in the options, this will return null.
-     *  Use getHost() if you need the host name.
+     *  As of 0.9.32, this works for literal IP addresses only, and does NOT resolve hostnames.
+     *  If a hostname is specified in the options, this will return null.
+     *  Use getHost() if you need the hostname.
      *
      *  @return IP or null
      *  @since 0.9.3
@@ -228,7 +228,7 @@ public class RouterAddress extends DataStructureImpl {
         if (_ip == NOT_LOOKED_UP) {
             // Only look up once, even if it fails, so we don't generate excessive DNS lookups.
             // The lifetime of a RouterAddress object is a few hours at most,
-            // it will get republished or expired, so it's OK even for host names.
+            // it will get republished or expired, so it's OK even for hostnames.
             String host = getHost();
             if (host != null)
                 _ip = Addresses.getIPOnly(host);
diff --git a/router/java/src/net/i2p/router/client/LookupDestJob.java b/router/java/src/net/i2p/router/client/LookupDestJob.java
index afac51f55039018b84a7adeadc39c3229977ddc8..e983c4e6023da55b75657324488992d7e24a6861 100644
--- a/router/java/src/net/i2p/router/client/LookupDestJob.java
+++ b/router/java/src/net/i2p/router/client/LookupDestJob.java
@@ -26,7 +26,7 @@ import net.i2p.util.Log;
 
 /**
  * Look up the lease of a hash, to convert it to a Destination for the client.
- * Or, since 0.9.11, lookup a host name in the naming service.
+ * Or, since 0.9.11, lookup a hostname in the naming service.
  */
 class LookupDestJob extends JobImpl {
     private final Log _log;
diff --git a/router/java/src/net/i2p/router/client/SSLClientListenerRunner.java b/router/java/src/net/i2p/router/client/SSLClientListenerRunner.java
index a6400c3ae2d9928ac599e3597fd69806fb9fc80d..450e154b6a9e408d811bed455a27f69cde86111e 100644
--- a/router/java/src/net/i2p/router/client/SSLClientListenerRunner.java
+++ b/router/java/src/net/i2p/router/client/SSLClientListenerRunner.java
@@ -97,7 +97,7 @@ class SSLClientListenerRunner extends ClientListenerRunner {
         if (success) {
             _log.logAlways(Log.INFO, "Created self-signed certificate for " + cname + " in keystore: " + ks.getAbsolutePath() + "\n" +
                            "The certificate was generated randomly, and is not associated with your " +
-                           "IP address, host name, router identity, or destination keys.");
+                           "IP address, hostname, router identity, or destination keys.");
         } else {
             _log.error("Failed to create I2CP SSL keystore.\n" +
                        "This is for the Sun/Oracle keytool, others may be incompatible.\n" +
diff --git a/router/java/src/net/i2p/router/transport/CommSystemFacadeImpl.java b/router/java/src/net/i2p/router/transport/CommSystemFacadeImpl.java
index 7fe70a3a07fc665a3c5e539f38e4dd7b0db6debe..cdcd28837c685725e077e0ecae2754ff9d7524c1 100644
--- a/router/java/src/net/i2p/router/transport/CommSystemFacadeImpl.java
+++ b/router/java/src/net/i2p/router/transport/CommSystemFacadeImpl.java
@@ -405,7 +405,7 @@ public class CommSystemFacadeImpl extends CommSystemFacade {
      * Collect the IPs for all routers in the DB, and queue them for lookup,
      * then fire off the periodic lookup task for the first time.
      *
-     *  As of 0.9.32, works only for literal IPs, ignores host names.
+     *  As of 0.9.32, works only for literal IPs, ignores hostnames.
      */
     private class QueueAll implements SimpleTimer.TimedEvent {
         public void timeReached() {
@@ -508,7 +508,7 @@ public class CommSystemFacadeImpl extends CommSystemFacade {
      *  Not recommended for our local router hash, as we may not be either in the cache or netdb,
      *  or may not be publishing an IP.
      *
-     *  As of 0.9.32, works only for literal IPs, returns null for host names.
+     *  As of 0.9.32, works only for literal IPs, returns null for hostnames.
      *
      *  @param peer not ourselves - use getOurCountry() for that
      *  @return two-letter lower-case country code or null
@@ -532,7 +532,7 @@ public class CommSystemFacadeImpl extends CommSystemFacade {
      *  Return first IP (v4 or v6) we find, any transport.
      *  Not validated, may be local, etc.
      *
-     *  As of 0.9.32, works only for literal IPs, returns null for host names.
+     *  As of 0.9.32, works only for literal IPs, returns null for hostnames.
      *
      *  @return IP or null
      */
@@ -549,7 +549,7 @@ public class CommSystemFacadeImpl extends CommSystemFacade {
      *  Return first valid IP (v4 or v6) we find, any transport.
      *  Local and other invalid IPs will not be returned.
      *
-     *  As of 0.9.32, works only for literal IPs, returns null for host names.
+     *  As of 0.9.32, works only for literal IPs, returns null for hostnames.
      *
      *  @return IP or null
      *  @since 0.9.18
diff --git a/router/java/src/net/i2p/router/transport/ntcp/EventPumper.java b/router/java/src/net/i2p/router/transport/ntcp/EventPumper.java
index 16596beedcae59803830061c6ede3e074649117c..60e43d80553b9e9e5fb9be7825bcf04f40f5a394 100644
--- a/router/java/src/net/i2p/router/transport/ntcp/EventPumper.java
+++ b/router/java/src/net/i2p/router/transport/ntcp/EventPumper.java
@@ -865,7 +865,7 @@ class EventPumper implements Runnable {
                 con.setKey(key);
                 RouterAddress naddr = con.getRemoteAddress();
                 try {
-                    // no DNS lookups, do not use host names
+                    // no DNS lookups, do not use hostnames
                     int port = naddr.getPort();
                     byte[] ip = naddr.getIP();
                     if (port <= 0 || ip == null)
diff --git a/router/java/src/net/i2p/router/transport/udp/UDPAddress.java b/router/java/src/net/i2p/router/transport/udp/UDPAddress.java
index 90be082819d633d7aad61f619d586fafe32c8895..83a8e7a7709b8d0bfb6750952211ce8acc1b7a32 100644
--- a/router/java/src/net/i2p/router/transport/udp/UDPAddress.java
+++ b/router/java/src/net/i2p/router/transport/udp/UDPAddress.java
@@ -205,7 +205,7 @@ class UDPAddress {
     public String getHost() { return _host; }
 
     /**
-     *  As of 0.9.32, will NOT resolve host names.
+     *  As of 0.9.32, will NOT resolve hostnames.
      *
      *  @return InetAddress or null
      */
@@ -228,7 +228,7 @@ class UDPAddress {
     int getIntroducerCount() { return (_introAddresses == null ? 0 : _introAddresses.length); }
 
     /**
-     *  As of 0.9.32, will NOT resolve host names.
+     *  As of 0.9.32, will NOT resolve hostnames.
      *
      *  @throws NullPointerException if getIntroducerCount() == 0
      *  @throws ArrayIndexOutOfBoundsException if i &lt; 0 or i &gt;= getIntroducerCount()
@@ -321,7 +321,7 @@ class UDPAddress {
     /**
      *  Caching version of InetAddress.getByName(host), which is slow.
      *  Caches numeric IPs only.
-     *  As of 0.9.32, will NOT resolve host names.
+     *  As of 0.9.32, will NOT resolve hostnames.
      *
      *  Unlike InetAddress.getByName(), we do NOT allow numeric IPs
      *  of the form d.d.d, d.d, or d, as these are almost certainly mistakes.
diff --git a/router/java/src/org/cybergarage/upnp/ssdp/SSDPPacket.java b/router/java/src/org/cybergarage/upnp/ssdp/SSDPPacket.java
index e198818f23448591241ed5635d397dae11ce747f..b9219c29b1f859c100cd6b710ce862ba6425c8a8 100644
--- a/router/java/src/org/cybergarage/upnp/ssdp/SSDPPacket.java
+++ b/router/java/src/org/cybergarage/upnp/ssdp/SSDPPacket.java
@@ -17,7 +17,7 @@
 *		- Fixed isRootDevice() to check the ST header.
 *	11/19/04
 *		- Theo Beisch <theo.beisch@gmx.de>
-*		- Changed getRemoteAddress() to return the adresss instead of the host name.
+*		- Changed getRemoteAddress() to return the adresss instead of the hostname.
 *
 ******************************************************************/
diff --git a/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/I2PTunnelHTTPClient.java b/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/I2PTunnelHTTPClient.java
index 0ab4440835210c5d9a3d7d178bcdb01724a0928e..96e1bcdaa07596e694efa1f5b839bc0153800b86 100644
--- a/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/I2PTunnelHTTPClient.java
+++ b/apps/i2ptunnel/java/src/net/i2p/i2ptunnel/I2PTunnelHTTPClient.java
@@ -64,7 +64,7 @@ import net.i2p.util.PortMapper;
  * resolve correctly, cookies won't work, etc.
  *
  * Note that http://$b64key/... and http://$b64key.i2p/... are NOT supported, as
  * a b64 key may contain '=' and '~', both of which are illegal host name characters.
  * Rewrite as http://i2p/$b64key/...
  *
  * If the $site resolves with the I2P naming service, then it is directed towards
@@ -76,7 +76,7 @@ import net.i2p.util.PortMapper;
 public class I2PTunnelHTTPClient extends I2PTunnelHTTPClientBase implements Runnable {
 
     /**
      *  Map of host name to base64 destination for destinations collected
      *  via address helper links
      */
     private final ConcurrentHashMap<String, String> addressHelpers = new ConcurrentHashMap<String, String>(8);
@@ -172,8 +172,8 @@ public class I2PTunnelHTTPClient extends I2PTunnelHTTPClientBase implements Runn
             "Proxy-Connection: close\r\n"+
             "\r\n" +
             "<html><body><H1>New Host Name with Address Helper</H1>" +
-            "The address helper link you followed is for a new host name that is not in your address book. " +
-            "You may either save the destination for this host name to your address book, or remember it only until your router restarts. " +
+            "The address helper link you followed is for a new hostname that is not in your address book. " +
+            "You may either save the destination for this hostname to your address book, or remember it only until your router restarts. " +
             "If you save it to your address book, you will not see this message again. " +
             "If you do not wish to visit this host, click the \"back\" button on your browser.";
 
@@ -573,7 +573,7 @@ public class I2PTunnelHTTPClient extends I2PTunnelHTTPClientBase implements Runn
 
                     int port = requestURI.getPort();
 
-                    // Go through the various types of host names, set
+                    // Go through the various types of hostnames, set
                     // the host and destination variables accordingly,
                     // and transform the first line.
                     // For all i2p network hosts, ensure that the host is a
@@ -622,7 +622,7 @@ public class I2PTunnelHTTPClient extends I2PTunnelHTTPClientBase implements Runn
                             break;
                         }
                     } else if(hostLowerCase.endsWith(".i2p")) {
                         // Destination gets the host name
                         destination = host;
                         // Host becomes the destination's "{b32}.b32.i2p" string, or "i2p" on lookup failure
                         host = getHostName(destination);
@@ -911,7 +911,7 @@ public class I2PTunnelHTTPClient extends I2PTunnelHTTPClientBase implements Runn
                             // ignore
                         }
                         return;
-                    }   // end host name processing
+                    }   // end hostname processing
 
                     boolean isValid = usingInternalOutproxy || usingWWWProxy ||
                                       usingInternalServer || isSupportedAddress(host, protocol);
@@ -1006,7 +1006,7 @@ public class I2PTunnelHTTPClient extends I2PTunnelHTTPClientBase implements Runn
                                         line = null;
                                         continue; // completely strip the line if everything doesn't match
                                     }
                                     // Strip to a relative URI, to hide the original host name
                                     StringBuilder buf = new StringBuilder();
                                     buf.append("Referer: ");
                                     String refererPath = refererURI.getRawPath();
@@ -64,7 +64,7 @@ import net.i2p.util.PortMapper;
  *
  * Note that http://$b64key/... and http://$b64key.i2p/... are NOT supported, as
- * a b64 key may contain '=' and '~', both of which are illegal host name characters.
+ * a b64 key may contain '=' and '~', both of which are illegal hostname characters.
  * Rewrite as http://i2p/$b64key/...
  *
@@ -76,7 +76,7 @@ import net.i2p.util.PortMapper;
 
     /**
-     *  Map of host name to base64 destination for destinations collected
+     *  Map of hostname to base64 destination for destinations collected
      *  via address helper links
      */
@@ -622,7 +622,7 @@ public class I2PTunnelHTTPClient extends I2PTunnelHTTPClientBase implements Runn
                         }
                     } else if(hostLowerCase.endsWith(".i2p")) {
-                        // Destination gets the host name
+                        // Destination gets the hostname
                         destination = host;
                         // Host becomes the destination's "{b32}.b32.i2p" string, or "i2p" on lookup failure
@@ -1006,7 +1006,7 @@ public class I2PTunnelHTTPClient extends I2PTunnelHTTPClientBase implements Runn
                                         continue; // completely strip the line if everything doesn't match
                                     }
-                                    // Strip to a relative URI, to hide the original host name
+                                    // Strip to a relative URI, to hide the original hostname
                                     StringBuilder buf = new StringBuilder();
                                     buf.append("Referer: ");